@@ -19,22 +19,20 @@
 #define ITEMDELEGATE_H
 
 #include <QStyledItemDelegate>
+#include <QPainter>
+#include <QStyleOptionViewItem>
 
 class ItemDelegate : public QStyledItemDelegate
 {
-  public:
-    using QStyledItemDelegate::QStyledItemDelegate;
+    Q_OBJECT
+
+public:
+    explicit ItemDelegate(QObject *parent = nullptr);
     bool displayRoleEnabled = false;
 
-  protected:
-    void initStyleOption(QStyleOptionViewItem *_styleOption, const QModelIndex &_modInd) const override
-    {
-      QStyledItemDelegate::initStyleOption(_styleOption, _modInd);
-      if (!displayRoleEnabled)
-      {
-        _styleOption->features &= ~QStyleOptionViewItem::HasDisplay;
-      }
-    }
+protected:
+    void initStyleOption(QStyleOptionViewItem *_styleOption, const QModelIndex &_modInd) const override;
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 };
 
 #endif // ITEMDELEGATE_H
