@@ -10,7 +10,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
@@ -66,6 +66,11 @@ MainWindow::MainWindow(QWidget *parent)
       _screenCurrentlyLocked(false),
       _needsRefreshAfterUnlock(false)
 {
+    _AppFileDir       = QDir::homePath()+"/.UltimateDailyWallpaper";
+    _databaseFilePath = _AppFileDir+"/udw_database.sqlite";
+    _confFile         = _AppFileDir+"/settings.conf";
+    _thumbfiledir     = _AppFileDir+"/thumbnails";
+
     QObject::connect(this, &MainWindow::_setWallpaper, [=](QString _wallpaperfile, int _set_Parameter, int _change_lockscreen_wallpaper)
     {
             setwall._set_wallpaper(_wallpaperfile, _set_Parameter, _change_lockscreen_wallpaper);
@@ -74,11 +79,6 @@ MainWindow::MainWindow(QWidget *parent)
     qApp->setAttribute(Qt::AA_DontShowIconsInMenus, false);
     qApp->setQuitOnLastWindowClosed(false);
 
-    _databaseFilePath = QDir::homePath()+"/.UltimateDailyWallpaper/udw_database.sqlite";
-    _AppFileDir = QDir::homePath()+"/.UltimateDailyWallpaper";
-    _confFile = _AppFileDir+"/"+"settings.conf";
-    _thumbfiledir = QDir::homePath()+"/.UltimateDailyWallpaper/thumbnails";
-
     QDir _settDir(_AppFileDir);
     if(!_settDir.exists())
     {
@@ -107,23 +107,42 @@ MainWindow::MainWindow(QWidget *parent)
     if(!confFile.exists(_confFile))
     {
         QString langfilesdir;
+
 #if defined(Q_OS_LINUX)
-        if(detect_pluginDir()==false)
+        plugdir=PLUGINS_DIR;
+
+        QDir dir(plugdir);
+
+        if (!dir.exists())
         {
             QMessageBox::StandardButton reply;
-            reply = QMessageBox::question(0, tr("Reset"), tr("The folder that containing the plugins was not found. "
-                                                                "Do you want to set the folder manually?"),
-                                                QMessageBox::Yes|QMessageBox::No);
+            reply = QMessageBox::question(0, tr("Reset"), tr("The folder containing the plugins was not found. "
+                                                            "Do you want to set the folder manually?"),
+                                            QMessageBox::Yes | QMessageBox::No);
 
-            if (reply == QMessageBox::Yes)
-            {
-                plugdir = QFileDialog::getExistingDirectory(this, tr("Select directory"),
-                                                             QDir::homePath(),
-                                                             QFileDialog::ShowDirsOnly
-                                                             | QFileDialog::DontResolveSymlinks);
+            if (reply == QMessageBox::Yes) {
+                // If the user clicks "Yes", open a file dialog to select the folder
+                plugdir = QFileDialog::getExistingDirectory(this, tr("Select Plugin Folder"),
+                                                            QDir::homePath(),
+                                                            QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
+            }
+        } else {
+            // If the folder exists, check if *.so* files are present
+            QFileInfoList soFiles = dir.entryInfoList(QStringList() << "*.so*", QDir::Files);
+
+            if (soFiles.isEmpty()) {
+                QMessageBox::warning(this, tr("No Plugins Found"),
+                                    tr("The folder does not contain any plugin files (*.so). Please choose a valid plugin folder."));
             }
         }
-        langfilesdir="/usr/share/locale";
+
+
+        /* ****************************************************
+         * Set the path where the translation files are stored
+         * **************************************************** */
+
+        langfilesdir=TR_PATH;
+
 #elif defined(Q_OS_MACOS)
         plugdir=QApplication::applicationDirPath()+"/"+"plugins";
         langfilesdir=QApplication::applicationDirPath()+"/"+"locale";
@@ -170,22 +189,18 @@ MainWindow::MainWindow(QWidget *parent)
     {
         _used_desktop=1;
     }
-    else if(_current_desktop=="XFCE")
+    else if(_current_desktop=="LXDE")
     {
         _used_desktop=2;
     }
-    else if(_current_desktop=="LXDE")
+    else if(_current_desktop=="MATE")
     {
         _used_desktop=3;
     }
-    else if(_current_desktop=="MATE")
+    else if(_current_desktop=="Trinity" || _current_desktop=="TDE")
     {
         _used_desktop=4;
     }
-    else if(_current_desktop=="Trinity")
-    {
-        _used_desktop=5;
-    }
     else if(_current_desktop=="KDE")
     {
         QString kdefullsession=qgetenv("KDE_FULL_SESSION");
@@ -193,20 +208,23 @@ MainWindow::MainWindow(QWidget *parent)
 
         if(kdefullsession=="true" && kdeversion=="5")
         {
-            _used_desktop=6;
+            _used_desktop=5;
+        } else if(kdefullsession=="true" && kdeversion=="6")
+        {
+            _used_desktop=9;
         }
     }
     else if(_current_desktop=="LXQt")
     {
-        _used_desktop=7;
+        _used_desktop=6;
     }
     else if(_current_desktop=="Deepin")
     {
-        _used_desktop=8;
+        _used_desktop=7;
     }
     else if(_current_desktop=="GNOME-Flashback" || _current_desktop=="GNOME-Classic:GNOME")
     {
-        _used_desktop=9;
+        _used_desktop=8;
     }
 
     set_used_desktop(_used_desktop);
@@ -221,9 +239,9 @@ MainWindow::MainWindow(QWidget *parent)
 
     QString _locale=QLocale::system().name();
 
-    /* **********************************************
-     * Untranslated .po files serve as placeholders.
-     * ***********************************************/
+    /* ***************************************************
+     * Untranslated language files serve as placeholders.
+     * ***************************************************/
 
     if(!(_applang==_locale))
     {
@@ -278,26 +296,30 @@ MainWindow::MainWindow(QWidget *parent)
         {
             _applang="ko";
             change_applang(_applang);
-        }        
+        }
         else if (_locale.contains("ca"))
         {
             _applang="ca";
             change_applang(_applang);
         }
+        else if (_locale.contains("en"))
+        {
+            _applang="en";
+            change_applang(_applang);
+        }
     }
 
-    QString _loadpath;
+    if (_applang != "en")
+    {
+        QString langfilename=QApplication::applicationName()+"_"+_applang;
 
-#if defined(Q_OS_LINUX)
-    _loadpath=_langfilesdir+"/"+_applang+"/LC_MESSAGES";
-#elif defined(Q_OS_MACOS)
-    _loadpath=_langfilesdir;
-#endif
-
-    QString langfilename="UltimateDailyWallpaper_"+_applang;
-
-    translator->load(_loadpath+"/"+langfilename);
-    qApp->installTranslator(translator);
+        if (!translator->load(_langfilesdir + "/" + langfilename))
+        {
+            qDebug()<<_langfilesdir + "/" + langfilename;
+            qWarning() << "Failed to load translation file:" << langfilename;
+        }
+        qApp->installTranslator(translator);
+    }
 
     detectPlugins();
 
@@ -308,7 +330,7 @@ MainWindow::MainWindow(QWidget *parent)
     }
 
     if (loadPlugin(_selected_plugin))
-    {        
+    {
         qDebug().noquote()<<tr("done.");
         qDebug().noquote()<<tr("Used plugin: ")+_selected_plugin<<"/"<<basicinterface->pluginname();
     }
@@ -320,7 +342,7 @@ MainWindow::MainWindow(QWidget *parent)
     /* read variable $XDG_CONFIG_HOME.
      * If the variable is empty then set default directory $HOME/.config
      * If the variable contains more than one directory (e.g. PATH1:PATH2...)
-     * then split by ":" and select the first directory as autostartDir. */  
+     * then split by ":" and select the first directory as autostartDir. */
 
     QString _confDirVariable = qgetenv("XDG_CONFIG_HOME");
     QString _autorun_location;
@@ -355,16 +377,19 @@ MainWindow::MainWindow(QWidget *parent)
     if(_autorun==2)
     {
         if(!autorun_file.exists())
-        {            
+        {
 #if defined(Q_OS_LINUX)
+            QString install_path=INSTALLATION_PATH; // Path of the Installation
+            QString bin_path=BINDIR_PATH;           // BIN_DIR
+
             QString _autorun_file_content =
                 "[Desktop Entry]\n"
                 "Type=Application\n"
-                "Exec=/usr/bin/UltimateDailyWallpaper\n"
+                "Exec="+bin_path+"/"+QApplication::applicationName()+"\n"
                 "Hidden=false\n"
                 "Name="+QApplication::applicationName()+"\n"
                 "Terminal=false\n"
-                "Icon=/usr/share/pixmaps/ultimatedesktopwallpaper_icon.png";           
+                "Icon="+install_path+"/ultimatedesktopwallpaper_icon.png";
 #elif defined(Q_OS_MACOS)
             QString _autorun_file_content =
                 "<?xml version=\"+APP_VERSION+\" encoding=\"UTF-8\"?>\n"
@@ -381,7 +406,7 @@ MainWindow::MainWindow(QWidget *parent)
                 "<string>"+QApplication::applicationName()+"</string>\n"
                 "</dict>\n"
                 "</plist>\n";
-#endif            
+#endif
             if (autorun_file.open(QIODevice::Append))
             {
                 QTextStream stream(&autorun_file);
@@ -490,10 +515,49 @@ MainWindow::~MainWindow()
 
 void MainWindow::slotActive(QSystemTrayIcon::ActivationReason r)
 {
+#if QT_VERSION >= 0x060000
+    if (r == QSystemTrayIcon::Trigger)
+    {
+        QPoint cursorPos = QCursor::pos();
+
+        QScreen *screen = QGuiApplication::screenAt(cursorPos);
+
+        if (screen)
+        {
+            QRect screenGeometry = screen->geometry();
+
+            QRect trayIconGeometry = mSystemTrayIcon->geometry();
+            Q_UNUSED(trayIconGeometry);
+
+            QPoint menuPos = cursorPos;
+
+            int menuWidth = basemenu->sizeHint().width();
+            int menuHeight = basemenu->sizeHint().height();
+
+            if (cursorPos.y() + menuHeight > screenGeometry.bottom())
+            {
+                menuPos.setY(cursorPos.y() - menuHeight);
+            }
+
+            if (cursorPos.x() + menuWidth > screenGeometry.right())
+            {
+
+                menuPos.setX(screenGeometry.right() - menuWidth);
+            }
+            else if (cursorPos.x() < screenGeometry.left())
+            {
+
+                menuPos.setX(screenGeometry.left());
+            }
+            basemenu->popup(menuPos);
+        }
+    }
+#else
     if (r == QSystemTrayIcon::Trigger)
     {
         basemenu->exec(QCursor::pos());
     }
+#endif
 }
 
 void MainWindow::set_autochange()
@@ -813,7 +877,7 @@ void MainWindow::create_Actions()
     connect(aboutapp, &QAction::triggered, this, &MainWindow::basemnu_aboutapp);
 
     quitapp = new QAction(tr("&Quit"), this);
-    connect(quitapp, SIGNAL(triggered()), qApp, SLOT(quit()));
+    connect(quitapp, &QAction::triggered, qApp, &QCoreApplication::quit);
 }
 
 void MainWindow::wikimedia_commons_more_pictures()
@@ -1193,10 +1257,6 @@ void MainWindow::update_menu()
 {
     basemenu->clear();
 
-    translator=new QTranslator;
-    translator->load(_applang);
-    qApp->installTranslator(translator);
-
     if(_record_out.last().isEmpty())
     {
         create_MenuHead(_record_out.at(0), _record_out.at(1), _record_out.at(4));
@@ -1282,9 +1342,9 @@ void MainWindow::_add_record(QString _description,
                              bool tempdatabase,
                              QString potd_date)
 {
-    /* ================================
-     * 0. VALIDIERUNG – Pflichtfelder prüfen
-     * ================================ */
+    // =======================================
+    // 0. Validate required fields
+    // =======================================
     if (_provider.isEmpty() ||
         _title_headline.isEmpty() ||
         _filename.isEmpty() ||
@@ -1301,136 +1361,119 @@ void MainWindow::_add_record(QString _description,
         return;
     }
 
-    /* ================================
-     * 1. Thread-local DB-Connection
-     * ================================ */
+    // =======================================
+    // 1. Create a thread-local DB connection
+    // =======================================
     QString connectionName =
         QString("udw_conn_%1")
         .arg(reinterpret_cast<quintptr>(QThread::currentThread()));
 
-    QSqlDatabase udw_db;
-
-    if (QSqlDatabase::contains(connectionName))
+    // Use a local scope to ensure the database is destroyed before removeDatabase()
     {
-        udw_db = QSqlDatabase::database(connectionName);
-    }
-    else
-    {
-        udw_db = QSqlDatabase::addDatabase("QSQLITE", connectionName);
-    }
+        QSqlDatabase udw_db = QSqlDatabase::addDatabase("QSQLITE", connectionName);
 
-    QString dbPath;
+        QString dbPath;
+        if (tempdatabase)
+            dbPath = _AppFileDir+"/temp/temp_udw_database.sqlite";
+        else
+            dbPath = _databaseFilePath;
 
-    if (tempdatabase)
-    {
-        dbPath = QDir::homePath()
-               + "/.UltimateDailyWallpaper/temp/temp_udw_database.sqlite";
-    }
-    else
-    {
-        dbPath = _databaseFilePath;
-    }
+        udw_db.setDatabaseName(dbPath);
 
-    udw_db.setDatabaseName(dbPath);
+        // Attempt to open the database
+        if (!udw_db.open()) {
+            qCritical() << "[DB] Cannot open database:" << udw_db.lastError();
+            QSqlDatabase::removeDatabase(connectionName);
+            return;
+        }
 
-    if (!udw_db.open())
-    {
-        qCritical() << "[DB] Cannot open database:" << udw_db.lastError();
-        QSqlDatabase::removeDatabase(connectionName);
-        return;
-    }
+        // =======================================
+        // 2. Start transaction
+        // =======================================
+        if (!udw_db.transaction()) {
+            qCritical() << "[DB] Cannot start transaction:" << udw_db.lastError();
+            udw_db.close();
+            QSqlDatabase::removeDatabase(connectionName);
+            return;
+        }
 
-    /* ================================
-     * 2. Start transaction
-     * ================================ */
-    if (!udw_db.transaction())
-    {
-        qCritical() << "[DB] Cannot start transaction:" << udw_db.lastError();
+        // =======================================
+        // 3. Prepare query
+        // =======================================
+        QSqlQuery udw_query(udw_db);
+
+        if (tempdatabase)
+        {
+            udw_query.prepare(
+                "INSERT INTO udw_history "
+                "(id, date, description, copyright, title, provider, filename, "
+                "browser_url, size_width, size_height, thumb_filename, pageid, potd_date) "
+                "VALUES "
+                "(:id, :date, :description, :copyright, :title, :provider, :filename, "
+                ":browser_url, :size_width, :size_height, :thumb_filename, :pageid, :potd_date)"
+            );
+        }
+        else
+        {
+            udw_query.prepare(
+                "INSERT INTO udw_history "
+                "(id, date, description, copyright, title, provider, filename, "
+                "browser_url, size_width, size_height, thumb_filename, pageid) "
+                "VALUES "
+                "(:id, :date, :description, :copyright, :title, :provider, :filename, "
+                ":browser_url, :size_width, :size_height, :thumb_filename, :pageid)"
+            );
+        }
+
+        // =======================================
+        // 4. Bind values
+        // =======================================
+        udw_query.bindValue(":id", QDateTime::currentDateTimeUtc().toString("yyyyMMddHHmmsszzz"));
+        udw_query.bindValue(":date", QDate::currentDate().toString("yyyyMMdd"));
+        udw_query.bindValue(":description", _description);
+        udw_query.bindValue(":copyright", _copyright);
+        udw_query.bindValue(":title", _title_headline);
+        udw_query.bindValue(":provider", _provider);
+        udw_query.bindValue(":filename", _filename);
+        udw_query.bindValue(":browser_url", _browser_url);
+        udw_query.bindValue(":size_width", _size_width);
+        udw_query.bindValue(":size_height", _size_height);
+        udw_query.bindValue(":thumb_filename", _thumb_filename);
+        udw_query.bindValue(":pageid", pageid);
+
+        if (tempdatabase)
+            udw_query.bindValue(":potd_date", potd_date);
+
+        // =======================================
+        // 5. Execute insert
+        // =======================================
+        if (!udw_query.exec()) {
+            qCritical() << "[DB] INSERT failed:" << udw_query.lastError();
+            udw_db.rollback();
+            udw_db.close();
+            QSqlDatabase::removeDatabase(connectionName);
+            return;
+        }
+
+        // =======================================
+        // 6. Commit transaction
+        // =======================================
+        if (!udw_db.commit()) {
+            qCritical() << "[DB] Commit failed:" << udw_db.lastError();
+            udw_db.rollback();
+        }
+
+        // =======================================
+        // 7. Cleanup
+        // =======================================
+        udw_query.finish();
         udw_db.close();
-        QSqlDatabase::removeDatabase(connectionName);
-        return;
-    }
+    } // QSqlDatabase destroyed here
 
-    QSqlQuery udw_query(udw_db);
-
-    if (tempdatabase)
-    {
-        udw_query.prepare(
-            "INSERT INTO udw_history "
-            "(id, date, description, copyright, title, provider, filename, "
-            "browser_url, size_width, size_height, thumb_filename, pageid, potd_date) "
-            "VALUES "
-            "(:id, :date, :description, :copyright, :title, :provider, :filename, "
-            ":browser_url, :size_width, :size_height, :thumb_filename, :pageid, :potd_date)"
-        );
-    }
-    else
-    {
-        udw_query.prepare(
-            "INSERT INTO udw_history "
-            "(id, date, description, copyright, title, provider, filename, "
-            "browser_url, size_width, size_height, thumb_filename, pageid) "
-            "VALUES "
-            "(:id, :date, :description, :copyright, :title, :provider, :filename, "
-            ":browser_url, :size_width, :size_height, :thumb_filename, :pageid)"
-        );
-    }
-
-    /* ================================
-     * 3. Values bind
-     * ================================ */
-    udw_query.bindValue(":id",
-        QDateTime::currentDateTimeUtc().toString("yyyyMMddHHmmsszzz"));
-
-    udw_query.bindValue(":date",
-        QDate::currentDate().toString("yyyyMMdd"));
-
-    udw_query.bindValue(":description", _description);
-    udw_query.bindValue(":copyright", _copyright);
-    udw_query.bindValue(":title", _title_headline);
-    udw_query.bindValue(":provider", _provider);
-    udw_query.bindValue(":filename", _filename);
-    udw_query.bindValue(":browser_url", _browser_url);
-    udw_query.bindValue(":size_width", _size_width);
-    udw_query.bindValue(":size_height", _size_height);
-    udw_query.bindValue(":thumb_filename", _thumb_filename);
-    udw_query.bindValue(":pageid", pageid);
-
-    if (tempdatabase)
-    {
-        udw_query.bindValue(":potd_date", potd_date);
-    }
-
-    /* ================================
-     * 4. Execute insert
-     * ================================ */
-    if (!udw_query.exec())
-    {
-        qCritical() << "[DB] INSERT failed:" << udw_query.lastError();
-        udw_db.rollback();
-        udw_db.close();
-        QSqlDatabase::removeDatabase(connectionName);
-        return;
-    }
-
-    /* ================================
-     * 5. Commit
-     * ================================ */
-    if (!udw_db.commit())
-    {
-        qCritical() << "[DB] Commit failed:" << udw_db.lastError();
-        udw_db.rollback();
-    }
-
-    /* ================================
-     * 6. clean up
-     * ================================ */
-    udw_query.finish();
-    udw_db.close();
+    // Remove the connection after destruction to avoid Qt warnings
     QSqlDatabase::removeDatabase(connectionName);
 
-    qDebug() << "[DB] Record inserted:"
-             << _provider << "-" << _filename;
+    qDebug() << "[DB] Record inserted:" << _provider << "-" << _filename;
 }
 
 void MainWindow::detectPlugins()
@@ -1532,38 +1575,6 @@ bool MainWindow::loadPlugin(QString _pluginfilename)
     return false;
 }
 
-#if defined(Q_OS_LINUX)
-bool MainWindow::detect_pluginDir()
-{
-    QString usrpath="/usr";
-    QDir dir(usrpath);
-    QStringList libdirs;
-    for(int i=0; i<dir.entryList().size();i++)
-    {
-        if(dir.entryList().at(i).contains("lib"))
-        {
-            dir.cd(dir.entryList().at(i));
-            libdirs.append(dir.absolutePath());
-            dir.cdUp();
-        }
-    }
-    for(int j=0; j<libdirs.size();j++)
-    {
-        dir.cd(libdirs.at(j));
-        for(int k=0; k<dir.entryList().size();k++)
-        {
-            if(dir.entryList().at(k).contains("UltimateDailyWallpaper-plugins"))
-            {
-                dir.cd(dir.entryList().at(k));
-                plugdir=dir.absolutePath();
-                return true;
-            }
-        }
-    }
-    return false;
-}
-#endif
-
 bool MainWindow::same_date()
 {
     _last_change.clear();
