@@ -19,6 +19,8 @@
 #include "ui_photobrowser.h"
 #include "itemdelegate.h"
 
+#include <QSplitter>
+#include <QScrollArea>
 #include <QSize>
 #include <QFile>
 #include <QDir>
@@ -102,8 +104,58 @@ PhotoBrowser::~PhotoBrowser()
 
 void PhotoBrowser::init(int mode)
 {
+    // Set window size
+    this->resize(1220, 750);
+
     deltempdir();
 
+    ui->widget_2->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+    ui->widget_3->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+    ui->widget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+
+    /* **********************
+     * Initialize QSplitter *
+     * ********************** */
+
+    // QSplitter is child of ui->widget
+    QSplitter* splitter = new QSplitter(Qt::Horizontal, ui->widget);
+
+    // Remove widgets from the previous layout.
+    if (ui->widget->layout()) {
+        QLayoutItem* item;
+        while ((item = ui->widget->layout()->takeAt(0)) != nullptr) {
+            item->widget()->setParent(nullptr);
+            delete item;
+        }
+        delete ui->widget->layout();
+    }
+
+    // Add widgets to splitter
+    splitter->addWidget(ui->frame_4);
+    splitter->addWidget(ui->listView);
+    splitter->addWidget(ui->scrollArea);
+
+    // Set splitter in "widget"
+    QVBoxLayout* layout = new QVBoxLayout(ui->widget);
+    layout->addWidget(splitter);
+    layout->setContentsMargins(0,0,0,0);
+    splitter->setSizes({300, 500, 300});
+    splitter->setChildrenCollapsible(false);
+
+    ui->scrollArea->setMinimumSize(ui->scrollArea->minimumSize());
+    ui->frame_4->setMinimumSize(ui->frame_4->minimumSize());
+
+    // Index 0 = frame_4, Index 1 = listView, Index 2 = scrollArea
+    splitter->setSizes({
+        ui->frame_4->minimumWidth(),  // far left
+        500,                          // ListView (any starting value)
+        ui->scrollArea->minimumWidth()// far right
+    });
+
+    splitter->setStretchFactor(0, 0); // frame_4 will not expand
+    splitter->setStretchFactor(1, 1); // listView expands
+    splitter->setStretchFactor(2, 0); // scrollArea will not expand
+
     ui->listView->setResizeMode(QListView::Adjust);
     ui->listView->setFlow(QListView::LeftToRight);
     ui->listView->setSpacing(15);
@@ -112,7 +164,13 @@ void PhotoBrowser::init(int mode)
     ui->listView->setIconSize(QSize (_scaled_picture_width, _scaled_picture_height));
     ui->listView->setViewMode(QListView::IconMode);
     ui->listView->setMovement(QListView::Static);
-    ui->listView->setItemDelegate(new ItemDelegate(this));
+    ui->listView->setSelectionMode(QAbstractItemView::SingleSelection);
+    ui->listView->setSelectionBehavior(QAbstractItemView::SelectItems);
+    ui->listView->setFocusPolicy(Qt::NoFocus);
+    ui->listView->setUniformItemSizes(true);
+    ItemDelegate *delegate = new ItemDelegate(this);
+    delegate->displayRoleEnabled = false; // hide text
+    ui->listView->setItemDelegate(delegate);
 
 
     /* *************************************************
@@ -189,6 +247,7 @@ void PhotoBrowser::init(int mode)
         QStandardItem *item = new QStandardItem(icon, _thumbfilelist.at(i).toUtf8());
         model->setItem(i, item);
     }
+
     ui->listView->setModel(model);
 
     wallchanged = false;
@@ -209,7 +268,11 @@ void PhotoBrowser::init(int mode)
     _label_image_size = new QLabel(this);
 
     _layout_details = new QVBoxLayout();
-    ui->frame_2->setLayout(_layout_details);
+    ui->scrollArea->setLayout(_layout_details);
+
+    QWidget *scrollAreaWidgetContents = new QWidget();
+    scrollAreaWidgetContents->setLayout(_layout_details);
+    ui->scrollArea->setWidget(scrollAreaWidgetContents);
 
     _layout_details->addWidget(_label_Details);
     _layout_details->addSpacerItem(new QSpacerItem(0,20, QSizePolicy::Minimum,QSizePolicy::Minimum));
@@ -234,6 +297,8 @@ void PhotoBrowser::init(int mode)
     _layout_details->setAlignment(_getmoreInformations, Qt::AlignHCenter);
     _layout_details->addStretch();
 
+    ui->scrollArea->setWidgetResizable(true);
+
     _first_run=true;
     _display_details();
 }
@@ -279,98 +344,87 @@ void PhotoBrowser::setWallpaperFile()
 
 void PhotoBrowser::_get_values()
 {
-    QSqlDatabase udw_db;
-    QSqlQuery udw_query(udw_db);
+    QString connectionName = "PhotoBrowserConnection";
 
-    if(QSqlDatabase::contains("qt_sql_default_connection"))
+    // Scope sorgt dafür, dass db und query zerstört werden, bevor removeDatabase aufgerufen wird
     {
-      udw_db = QSqlDatabase::database("qt_sql_default_connection");
-    }
-    else
-    {
-      udw_db = QSqlDatabase::addDatabase("QSQLITE");
-    }
+        QSqlDatabase udw_db;
 
-    udw_db.setDatabaseName(_databaseFilePath);
+        if(QSqlDatabase::contains(connectionName))
+            udw_db = QSqlDatabase::database(connectionName);
+        else
+            udw_db = QSqlDatabase::addDatabase("QSQLITE", connectionName);
 
-    if(_get_specific_values==false)
-    {
-        udw_query.prepare("SELECT thumb_filename FROM udw_history");
-        udw_query.exec();
-        while(udw_query.next())
+        udw_db.setDatabaseName(_databaseFilePath);
+
+        if(!udw_db.open()) {
+            qDebug() << "Database could not be opened:" << udw_db.lastError().text();
+            return;
+        }
+
+        QSqlQuery udw_query(udw_db);
+
+        if(!_get_specific_values)
         {
-            if(!_thumbfilelist.contains(udw_query.value(0).toString().toUtf8()))
+            // Load all thumbnail filenames into list
+            if(!udw_query.exec("SELECT thumb_filename FROM udw_history")) {
+                qDebug() << "Error querying thumbnails:" << udw_query.lastError().text();
+                return;
+            }
+
+            while(udw_query.next())
             {
-                if(!(udw_query.value(0).toString().isEmpty()))
+                QByteArray thumb = udw_query.value(0).toString().toUtf8();
+                if(!_thumbfilelist.contains(thumb) && !thumb.isEmpty())
                 {
-                    _thumbfilelist.append(udw_query.value(0).toString().toUtf8());
+                    _thumbfilelist.append(thumb);
                 }
             }
         }
-    }
-    else
-    {
-        QModelIndex index = ui->listView->currentIndex();
-
-        _thumb_filename = index.data(Qt::DisplayRole).toString();
-
-        if(_thumb_filename.contains("\x27"))
+        else
         {
-            _thumb_filename.replace("\x27", "\x27\x27");
-        }
+            // Load specific image details for the selected thumbnail
+            QModelIndex index = ui->listView->currentIndex();
+            _thumb_filename = index.data(Qt::DisplayRole).toString();
 
-        QStringList _commands={"SELECT description FROM udw_history WHERE thumb_filename = \x27"+_thumb_filename+"\x27",
-                               "SELECT copyright FROM udw_history WHERE thumb_filename = \x27"+_thumb_filename+"\x27",
-                               "SELECT title FROM udw_history WHERE thumb_filename = \x27"+_thumb_filename+"\x27",
-                               "SELECT browser_url FROM udw_history WHERE thumb_filename = \x27"+_thumb_filename+"\x27",
-                               "SELECT size_width FROM udw_history WHERE thumb_filename = \x27"+_thumb_filename+"\x27",
-                               "SELECT size_height FROM udw_history WHERE thumb_filename = \x27"+_thumb_filename+"\x27",
-                               "SELECT filename FROM udw_history WHERE thumb_filename = \x27"+_thumb_filename+"\x27"
-                              };
+            udw_query.prepare("SELECT description, copyright, title, browser_url, size_width, size_height, filename "
+                              "FROM udw_history WHERE thumb_filename = :thumb_filename");
+            udw_query.bindValue(":thumb_filename", _thumb_filename);
 
-        QStringList _record_out;
-
-        for(int i=0; i<_commands.size();i++)
-        {
-            if(udw_query.exec(_commands.at(i)) && udw_query.next())
+            if(udw_query.exec() && udw_query.next())
             {
-                _record_out.append(udw_query.value(0).toString());
-            } else
-            {
-                qDebug() << udw_query.lastError().text();
+                _pb_copyright_description_photo = udw_query.value(0).toString();
+                _pb_copyright = udw_query.value(1).toString();
+                _pb_headline = udw_query.value(2).toString();
+                _pb_copyright_link = udw_query.value(3).toString();
+                _size_width = udw_query.value(4).toInt();
+                _size_height = udw_query.value(5).toInt();
+                _wallpaperfile = udw_query.value(6).toString();
             }
+            else
+            {
+                qDebug() << "Error querying image details:" << udw_query.lastError().text();
+            }
+
+            _get_specific_values = false;
         }
 
-        _pb_copyright_description_photo=_record_out.at(0);
-        _pb_copyright=_record_out.at(1);
-        _pb_headline=_record_out.at(2);
-        _pb_copyright_link=_record_out.at(3);
-        _size_width=_record_out.at(4).toInt();
-        _size_height=_record_out.at(5).toInt();
-        _wallpaperfile=_record_out.at(6);
+        udw_query.finish();
+    } // udw_query und udw_db gehen hier aus dem Scope -> Verbindung ist frei
 
-        _get_specific_values=false;
-
-        if(_thumb_filename.contains("\x27\x27"))
-        {
-            _thumb_filename.replace("\x27\x27", "\x27");
-        }
+    // Verbindung jetzt sicher entfernen, falls noch vorhanden
+    if(QSqlDatabase::contains(connectionName)) {
+        QSqlDatabase::removeDatabase(connectionName);
     }
 
-    udw_query.finish();
-    udw_query.clear();
-
-    QThread::msleep(100);
-    if (_wallpaperfile.isEmpty())
-    {
-        // Set a content in the qstring to avoid a crash
-        _wallpaperfile = "NULL";
-    }
+    // Avoid crash if wallpaper filename is empty
+    if (_wallpaperfile.isEmpty()) _wallpaperfile = "NULL";
 }
 
 void PhotoBrowser::on_listView_clicked()
 {
     _display_details();
+    ui->scrollArea->update();
 }
 
 void PhotoBrowser::_display_details()
@@ -391,7 +445,6 @@ void PhotoBrowser::_display_details()
 
         _label_headline1->setText(_pb_headline);
         _label_headline1->setWordWrap(true);
-        _label_headline1->setMaximumWidth(275);
 
         _label_description_and_copyright1->setStyleSheet("font-weight: bold;");
         _label_description_and_copyright1->setText(tr("Description: "));
@@ -405,7 +458,6 @@ void PhotoBrowser::_display_details()
         }
 
         _label_description_and_copyright->setWordWrap(true);
-        _label_description_and_copyright->setMaximumWidth(275);
 
         _label_image_size1->setText(tr("Picture size:"));
         _label_image_size1->setStyleSheet("font-weight: bold;");
@@ -525,36 +577,45 @@ void PhotoBrowser::show()
 
 bool PhotoBrowser::create_temp_database()
 {
-    QSqlDatabase udw_temp_db;
+    QString connectionName = "PhotoBrowserCreateTempDBConnection";
 
-    if(QSqlDatabase::contains("qt_sql_default_connection"))
     {
-        udw_temp_db = QSqlDatabase::database("qt_sql_default_connection");
-    }
-    else
-    {
-        udw_temp_db = QSqlDatabase::addDatabase("QSQLITE");
-    }
+        QSqlDatabase udw_temp_db;
 
-    udw_temp_db.setDatabaseName(_databaseFilePath);
+        if(QSqlDatabase::contains(connectionName))
+            udw_temp_db = QSqlDatabase::database(connectionName);
+        else
+            udw_temp_db = QSqlDatabase::addDatabase("QSQLITE", connectionName);
 
-    if (!udw_temp_db.open())
-    {
-        return false;
-    }
+        udw_temp_db.setDatabaseName(_databaseFilePath);
 
-    QSqlQuery udw_temp_query(udw_temp_db);
-    if(!udw_temp_db.tables().contains(QLatin1String("udw_history")))
-    {
-        udw_temp_query.exec("create table udw_history (id int primary key, "
-                   "date varchar(30), description varchar(900), copyright varchar(500),"
-                   "title varchar(500), provider varchar(100),"
-                   "filename varchar(150), browser_url varchar(500), size_width int, size_height int,"
-                   "thumb_filename varchar(150), pageid int, potd_date varchar(500))");
+        if (!udw_temp_db.open())
+        {
+            qDebug() << "Database could not be opened:" << udw_temp_db.lastError().text();
+            return false;
+        }
 
-        udw_temp_query.finish();
-        udw_temp_query.clear();
-    }
+        QSqlQuery udw_temp_query(udw_temp_db);
+
+        if(!udw_temp_db.tables().contains(QLatin1String("udw_history")))
+        {
+            if(!udw_temp_query.exec("create table udw_history (id int primary key, "
+                                    "date varchar(30), description varchar(900), copyright varchar(500),"
+                                    "title varchar(500), provider varchar(100),"
+                                    "filename varchar(150), browser_url varchar(500), size_width int, size_height int,"
+                                    "thumb_filename varchar(150), pageid int, potd_date varchar(500))"))
+            {
+                qDebug() << "Failed to create table:" << udw_temp_query.lastError().text();
+            }
+
+            udw_temp_query.finish();
+            udw_temp_query.clear();
+        }
+    } // udw_temp_db & udw_temp_query verlassen den Scope
+
+    // Verbindung entfernen
+    if(QSqlDatabase::contains(connectionName))
+        QSqlDatabase::removeDatabase(connectionName);
 
     return true;
 }
@@ -626,39 +687,61 @@ void PhotoBrowser::download_and_set()
 
 bool PhotoBrowser::select_single_value(QString desired_column, QString db_filepath)
 {
-    QSqlDatabase udw_temp_db;
-    QSqlQuery udw_query(udw_temp_db);
+    // Only allow valid columns
+    static const QStringList allowedColumns = {
+        "filename", "description", "copyright", "title",
+        "browser_url", "size_width", "size_height", "potd_date"
+    };
 
-    if(QSqlDatabase::contains("qt_sql_default_connection"))
-    {
-        udw_temp_db = QSqlDatabase::database("qt_sql_default_connection");
-    }
-    else
-    {
-        udw_temp_db = QSqlDatabase::addDatabase("QSQLITE");
-    }
-
-    udw_temp_db.setDatabaseName(db_filepath);
-
-    if (!udw_temp_db.open())
-    {
+    if(!allowedColumns.contains(desired_column)) {
+        qDebug() << "Invalid column requested:" << desired_column;
         return false;
     }
 
-    if(_thumb_filename.contains("\x27"))
+    QString connectionName = "PhotoBrowserSelectConnection";
+
+    // Scope sorgt dafür, dass db und query zerstört werden, bevor removeDatabase aufgerufen wird
+    bool result = false; // Rückgabewert
+
     {
-        _thumb_filename.replace("\x27", "\x27\x27");
+        QSqlDatabase udw_db;
+
+        if(QSqlDatabase::contains(connectionName))
+            udw_db = QSqlDatabase::database(connectionName);
+        else
+            udw_db = QSqlDatabase::addDatabase("QSQLITE", connectionName);
+
+        udw_db.setDatabaseName(db_filepath);
+
+        if(!udw_db.open()) {
+            qDebug() << "Database could not be opened:" << udw_db.lastError().text();
+            return false;
+        }
+
+        QSqlQuery udw_query(udw_db);
+        udw_query.prepare(QString("SELECT %1 FROM udw_history WHERE thumb_filename = :thumb_filename").arg(desired_column));
+        udw_query.bindValue(":thumb_filename", _thumb_filename);
+
+        if(udw_query.exec() && udw_query.next())
+        {
+            _output_value = udw_query.value(0).toString();
+            result = true;
+        }
+        else
+        {
+            qDebug() << "Error executing SELECT query:" << udw_query.lastError().text();
+            result = false;
+        }
+
+        udw_query.finish();
+    } // udw_query und udw_db gehen hier aus dem Scope -> Verbindung ist frei
+
+    // Verbindung jetzt sicher entfernen, falls noch vorhanden
+    if(QSqlDatabase::contains(connectionName)) {
+        QSqlDatabase::removeDatabase(connectionName);
     }
 
-    udw_query.prepare("SELECT "+desired_column+" FROM udw_history WHERE thumb_filename = \x27"+_thumb_filename+"\x27");
-    if(udw_query.exec() && udw_query.next())
-    {
-        _output_value = udw_query.value(0).toString();
-    }
-    udw_query.finish();
-    udw_query.clear();
-
-    return true;
+    return result;
 }
 
 void PhotoBrowser::deltempdir()
@@ -702,77 +785,78 @@ bool PhotoBrowser::loadPlugin(QString _pluginfile)
 }
 
 void PhotoBrowser::_add_record(QString _description,
-                             QString _copyright,
-                             QString _provider,
-                             QString _title_headline,
-                             QString _filename,
-                             QString _browser_url,
-                             QString _thumb_filename,
-                             int _size_height,
-                             int _size_width,
-                             int pageid,
-                             bool tempdatabase,
-                             QString potd_date)
+                               QString _copyright,
+                               QString _provider,
+                               QString _title_headline,
+                               QString _filename,
+                               QString _browser_url,
+                               QString _thumb_filename,
+                               int _size_height,
+                               int _size_width,
+                               int pageid,
+                               bool tempdatabase,
+                               QString potd_date)
 {
-    QSqlDatabase udw_db;
+    QString connectionName = "PhotoBrowserAddRecordConnection";
+    QString _tempdatabaseFilePath = QDir::homePath()+"/.UltimateDailyWallpaper/temp/temp_udw_database.sqlite";
 
-    QString _tempdatabaseFilePath=QDir::homePath()+"/.UltimateDailyWallpaper/temp/temp_udw_database.sqlite";
-
-    if(QSqlDatabase::contains("qt_sql_default_connection"))
     {
-        udw_db = QSqlDatabase::database("qt_sql_default_connection");
+        QSqlDatabase udw_db;
+
+        if(QSqlDatabase::contains(connectionName))
+            udw_db = QSqlDatabase::database(connectionName);
+        else
+            udw_db = QSqlDatabase::addDatabase("QSQLITE", connectionName);
+
+        if(tempdatabase)
+            udw_db.setDatabaseName(_tempdatabaseFilePath);
+        else
+            udw_db.setDatabaseName(_databaseFilePath);
+
+        if(!udw_db.open()) {
+            qDebug() << "Database could not be opened:" << udw_db.lastError().text();
+            return;
+        }
+
+        QSqlQuery udw_query(udw_db);
+
+        if(tempdatabase)
+        {
+            udw_query.prepare("INSERT INTO udw_history (id, date, description, copyright, title, provider, filename, browser_url, size_width, size_height, thumb_filename, pageid, potd_date)"
+                              "VALUES (:id, :date, :description, :copyright, :title, :provider, :filename, :browser_url, :size_width, :size_height, :thumb_filename, :pageid, :potd_date)");
+        }
+        else
+        {
+            udw_query.prepare("INSERT INTO udw_history (id, date, description, copyright, title, provider, filename, browser_url, size_width, size_height, thumb_filename, pageid)"
+                              "VALUES (:id, :date, :description, :copyright, :title, :provider, :filename, :browser_url, :size_width, :size_height, :thumb_filename, :pageid)");
+        }
+
+        udw_query.bindValue(":id", QDateTime::currentDateTime().toString("yyyyMMddHHmmsszzz"));
+        udw_query.bindValue(":date", QDate::currentDate().toString("yyyyMMdd"));
+        udw_query.bindValue(":description", _description);
+        udw_query.bindValue(":copyright", _copyright);
+        udw_query.bindValue(":title", _title_headline);
+        udw_query.bindValue(":provider", _provider);
+        udw_query.bindValue(":filename", _filename);
+        udw_query.bindValue(":browser_url", _browser_url);
+        udw_query.bindValue(":size_width", _size_width);
+        udw_query.bindValue(":size_height", _size_height);
+        udw_query.bindValue(":thumb_filename", _thumb_filename);
+        udw_query.bindValue(":pageid", pageid);
+
+        if(tempdatabase)
+            udw_query.bindValue(":potd_date", potd_date);
+
+        if(!udw_query.exec())
+            qDebug() << udw_query.lastError();
+
+        udw_query.finish();
+        udw_query.clear();
+    } // udw_query & udw_db verlassen den Scope -> Verbindung frei
+
+    // Verbindung entfernen
+    if(QSqlDatabase::contains(connectionName))
+    {
+        QSqlDatabase::removeDatabase(connectionName);
     }
-    else
-    {
-        udw_db = QSqlDatabase::addDatabase("QSQLITE");
-    }
-
-    if(tempdatabase==true)
-    {
-        udw_db.setDatabaseName(_tempdatabaseFilePath);
-    }
-    else
-    {
-        udw_db.setDatabaseName(_databaseFilePath);
-    }
-
-    udw_db.open();
-
-    QSqlQuery udw_query(udw_db);
-
-    if(tempdatabase==true)
-    {
-        udw_query.prepare("INSERT INTO udw_history (id, date, description, copyright, title, provider, filename, browser_url, size_width, size_height, thumb_filename, pageid, potd_date)"
-                                            "VALUES (:id, :date, :description, :copyright, :title, :provider, :filename, :browser_url, :size_width, :size_height, :thumb_filename, :pageid, :potd_date)");
-    } else
-    {
-        udw_query.prepare("INSERT INTO udw_history (id, date, description, copyright, title, provider, filename, browser_url, size_width, size_height, thumb_filename, pageid)"
-                                            "VALUES (:id, :date, :description, :copyright, :title, :provider, :filename, :browser_url, :size_width, :size_height, :thumb_filename, :pageid)");
-    }
-    udw_query.bindValue(":id", QDateTime::currentDateTime().toString("yyyyMMddHHmmsszzz"));
-    udw_query.bindValue(":date", QDate::currentDate().toString("yyyyMMdd"));
-    udw_query.bindValue(":description", _description);
-    udw_query.bindValue(":copyright", _copyright);
-    udw_query.bindValue(":title", _title_headline);
-    udw_query.bindValue(":provider", _provider);
-    udw_query.bindValue(":filename", _filename);
-    udw_query.bindValue(":browser_url", _browser_url);
-    udw_query.bindValue(":size_width", _size_width);
-    udw_query.bindValue(":size_height", _size_height);
-    udw_query.bindValue(":thumb_filename", _thumb_filename);
-    udw_query.bindValue(":pageid", pageid);
-
-    if(tempdatabase==true)
-    {
-        udw_query.bindValue(":potd_date", potd_date);
-    }
-
-    if(!udw_query.exec())
-    {
-        qDebug() << udw_query.lastError();
-    }
-
-    udw_query.finish();
-    udw_query.clear();
-    udw_db.close();
 }
