@@ -27,19 +27,11 @@ class setWallpaper: public QObject
 public:
     setWallpaper();
 
-signals:
-    void wallpaper_changed(QString _scriptfile);
-
 public slots:
     void _set_wallpaper(QString _wallpaperfile, int _Parameter, int _change_lockscreen_wallpaper);
 
 private:
-    QString out;
-    QStringList _detected_monitors;
-
-    int doProcess(QString command);
-    int _xfce4_detect_monitors();
-    void _set_wallpaper_script(QString _scriptfile, QString content);
+    int doProcess(QString command, QStringList arguments, int used_desktop);
 };
 
 #endif // SETWALLPAPER_H
